/* V2 Tabs CSS */
.tabs {
  display: flex;
  margin-bottom: 0;
}

.tab-button {
  padding: 10px 20px;
  background-color: var(--tab-background-color, #444);
  color: var(--tab-text-color, #ccc);
  border: 1px solid var(--border-color, #555);
  border-bottom: none;
  cursor: pointer;
  margin-right: 5px;
  border-radius: 5px 5px 0 0;
  transition:
    background-color 0.2s,
    color 0.2s;
}

.tab-button:hover {
  background-color: var(--tab-hover-background-color, #555);
}

.tab-button.active {
  background-color: var(--tab-active-background-color, #333);
  color: var(--tab-active-text-color, #fff);
  border-bottom: 1px solid var(--tab-active-background-color, #333);
  font-weight: bold;
}

.tab-content {
  display: block !important; /* Ensure content is visible */
  background: var(--container-background-color, #333);
  padding: 20px;
  border: 1px solid var(--border-color, #555);
  border-top: none;
  min-height: 200px;
}
