@keyframes spin {
  from {
    transform: rotate(0deg);
  }

  to {
    transform: rotate(360deg);
  }
}

.spin {
  animation: spin 1s linear infinite;
}

@keyframes marquee {
  0% {
    transform: translateX(0%);
  }

  100% {
    transform: translateX(-100%);
  }
}

.scrolling-text {
  display: inline-block;
  padding-left: 220px; /* Use fixed width (Sidebar width) to ensure consistent start pos */
  animation: marquee 15s linear infinite;
}

.scrolling-text.static {
  padding-left: 0;
  animation: none;
  white-space: normal; /* Allow wrap if static? Or keep nowrap */
  white-space: nowrap;
}

/* Pause animation on hover for readability */
.sidebar-header:hover .scrolling-text {
  animation-play-state: paused;
}
